@@ -1,6 +1,7 @@
 "use strict";
 
 module.exports = function(grunt) {
+	const currentYear = new Date().getFullYear();
 	grunt.initConfig({
 		nodeunit : {
 			zones : [
@@ -12,16 +13,20 @@ module.exports = function(grunt) {
 		},
 
 		build : {
-			'moment-timezone-with-data'           : true,
-			'moment-timezone-with-data-2012-2022' : [2012, 2022]
+			'moment-timezone-with-data'               : true,
+			'moment-timezone-with-data-1970-2030'     : [1970, 2030],
+			'moment-timezone-with-data-2012-2022'     : [2012, 2022],
+			'moment-timezone-with-data-10-year-range' : [currentYear - 5, currentYear + 5]
 		},
 
 		uglify : {
 			all: {
 				files: {
-					'builds/moment-timezone.min.js'                     : 'moment-timezone.js',
-					'builds/moment-timezone-with-data.min.js'           : 'builds/moment-timezone-with-data.js',
-					'builds/moment-timezone-with-data-2012-2022.min.js' : 'builds/moment-timezone-with-data-2012-2022.js'
+					'builds/moment-timezone.min.js'                         : 'moment-timezone.js',
+					'builds/moment-timezone-with-data.min.js'               : 'builds/moment-timezone-with-data.js',
+					'builds/moment-timezone-with-data-1970-2030.min.js'     : 'builds/moment-timezone-with-data-1970-2030.js',
+					'builds/moment-timezone-with-data-2012-2022.min.js'     : 'builds/moment-timezone-with-data-2012-2022.js',
+					'builds/moment-timezone-with-data-10-year-range.min.js' : 'builds/moment-timezone-with-data-10-year-range.js'
 				}
 			},
 			options: {
