@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Fort_Nelson"] = {
-	"guess" : helpers.makeTestGuess("America/Fort_Nelson", { offset: true, abbr: true, expect: "America/Phoenix" }),
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Fort_Nelson", { offset: true, expect: "America/Phoenix" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Fort_Nelson", { abbr: true, expect: "America/Phoenix" }),
 
 	"1918" : helpers.makeTestYear("America/Fort_Nelson", [
 		["1918-04-14T09:59:59+00:00", "01:59:59", "PST", 480],
@@ -498,10 +501,5 @@ exports["America/Fort_Nelson"] = {
 		["2014-03-09T10:00:00+00:00", "03:00:00", "PDT", 420],
 		["2014-11-02T08:59:59+00:00", "01:59:59", "PDT", 420],
 		["2014-11-02T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2015" : helpers.makeTestYear("America/Fort_Nelson", [
-		["2015-03-08T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2015-03-08T10:00:00+00:00", "03:00:00", "MST", 420]
 	])
 };
\ No newline at end of file
