@@ -4,9 +4,9 @@ var helpers = require("../../helpers/helpers");
 
 exports["America/Punta_Arenas"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Punta_Arenas", { offset: true, expect: "Antarctica/Palmer" }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Punta_Arenas", { offset: true, expect: "America/Fortaleza" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Punta_Arenas", { abbr: true, expect: "Antarctica/Palmer" }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Punta_Arenas", { abbr: true, expect: "America/Fortaleza" }),
 
 	"1910" : helpers.makeTestYear("America/Punta_Arenas", [
 		["1910-01-10T04:42:45+00:00", "23:59:59", "SMT", 16966 / 60],
@@ -413,8 +413,6 @@ exports["America/Punta_Arenas"] = {
 		["2016-05-15T02:59:59+00:00", "23:59:59", "-03", 180],
 		["2016-05-15T03:00:00+00:00", "23:00:00", "-04", 240],
 		["2016-08-14T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2016-08-14T04:00:00+00:00", "01:00:00", "-03", 180],
-		["2016-12-04T02:59:59+00:00", "23:59:59", "-03", 180],
-		["2016-12-04T03:00:00+00:00", "00:00:00", "-03", 180]
+		["2016-08-14T04:00:00+00:00", "01:00:00", "-03", 180]
 	])
 };
\ No newline at end of file
