@@ -3,10 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Ho_Chi_Minh"] = {
-	"1906" : helpers.makeTestYear("Asia/Ho_Chi_Minh", [
-		["1906-06-30T16:53:19+00:00", "23:59:59", "LMT", -25600 / 60],
-		["1906-06-30T16:53:20+00:00", "23:59:50", "PLMT", -25590 / 60]
-	]),
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Ho_Chi_Minh", { offset: true, expect: "Asia/Jakarta" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ho_Chi_Minh", { abbr: true, expect: "Asia/Jakarta" }),
 
 	"1911" : helpers.makeTestYear("Asia/Ho_Chi_Minh", [
 		["1911-04-30T16:53:29+00:00", "23:59:59", "PLMT", -25590 / 60],
@@ -38,10 +38,5 @@ exports["Asia/Ho_Chi_Minh"] = {
 	"1959" : helpers.makeTestYear("Asia/Ho_Chi_Minh", [
 		["1959-12-31T15:59:59+00:00", "22:59:59", "+07", -420],
 		["1959-12-31T16:00:00+00:00", "00:00:00", "+08", -480]
-	]),
-
-	"1975" : helpers.makeTestYear("Asia/Ho_Chi_Minh", [
-		["1975-06-12T15:59:59+00:00", "23:59:59", "+08", -480],
-		["1975-06-12T16:00:00+00:00", "23:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
