@@ -4,14 +4,9 @@ var helpers = require("../../helpers/helpers");
 
 exports["Asia/Ulan_Bator"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("Asia/Ulan_Bator", { offset: true, expect: "Asia/Ulaanbaatar" }),
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Ulan_Bator", { offset: true, expect: "Asia/Manila" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ulan_Bator", { abbr: true, expect: "Asia/Ulaanbaatar" }),
-
-	"1905" : helpers.makeTestYear("Asia/Ulan_Bator", [
-		["1905-07-31T16:52:27+00:00", "23:59:59", "LMT", -25652 / 60],
-		["1905-07-31T16:52:28+00:00", "23:52:28", "+07", -420]
-	]),
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ulan_Bator", { abbr: true, expect: "Asia/Manila" }),
 
 	"1977" : helpers.makeTestYear("Asia/Ulan_Bator", [
 		["1977-12-31T16:59:59+00:00", "23:59:59", "+07", -420],
@@ -181,8 +176,6 @@ exports["Asia/Ulan_Bator"] = {
 
 	"2016" : helpers.makeTestYear("Asia/Ulan_Bator", [
 		["2016-03-25T17:59:59+00:00", "01:59:59", "+08", -480],
-		["2016-03-25T18:00:00+00:00", "03:00:00", "+09", -540],
-		["2016-09-23T14:59:59+00:00", "23:59:59", "+09", -540],
-		["2016-09-23T15:00:00+00:00", "23:00:00", "+08", -480]
+		["2016-03-25T18:00:00+00:00", "03:00:00", "+09", -540]
 	])
 };
\ No newline at end of file
