@@ -4,9 +4,9 @@ var helpers = require("../helpers/helpers");
 
 exports["Turkey"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("Turkey", { offset: true, expect: "Europe/Istanbul" }),
+	"guess:by:offset" : helpers.makeTestGuess("Turkey", { offset: true, expect: "Europe/Moscow" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Turkey", { abbr: true, expect: "Europe/Istanbul" }),
+	"guess:by:abbr" : helpers.makeTestGuess("Turkey", { abbr: true, expect: "Europe/Moscow" }),
 
 	"1910" : helpers.makeTestYear("Turkey", [
 		["1910-09-30T22:03:03+00:00", "23:59:59", "IMT", -7016 / 60],
